Learn R Programming

unitedR (version 0.1)

unitedR-package: Assessment and Evaluation of United Formations

Description

Assessment and Evaluation of United Formations

Arguments

Details

ll{ Package: unitedR Type: Package Version: 0.1 Date: 2014-12-18 License: GPL (>= 2) LazyLoad: yes } This package provides functionality for the assessment of lineups and formations in United. The rules for United in detail can be found under: http://www.schroepl.net/pbm/software/united/_dokument/handbuch.htm{United-rules}.

References

http://www.omido.de/{omido} http://www.schroepl.net/pbm/software/united/{United}